# -*- coding: utf-8 -*-

# Copyright (c) 2009-2011 Christopher S. Case and David H. Bronke
# Licensed under the MIT license; see the LICENSE file for details.

"""Qt compatibility wrapper

Detects either PySide or PyQt.

"""
import sys
import logging

__all__ = [
        'QtCore', 'QtGui', 'QtNetwork', 'QtWebKit', 'QtUiTools', 'Signal',
        'Slot', 'loadUI'
        ]


logger = logging.getLogger("Qt")


def initialize(prefer="PySide"):
    if prefer.lower() in ["pyqt", "pyqt4"]:
        if not importPyQt():
            logger.warn("PyQt4 requested, but not installed.")

            if not importPySide():
                logger.error("Couldn't import PySide or PyQt4! You must have "
                        + "one or the other to run this app.")
                sys.exit(1)
    else:
        if not importPySide():
            logger.warn("PyQt4 requested, but not installed.")

            if not importPyQt():
                logger.error("Couldn't import PySide or PyQt4! You must have "
                        + "one or the other to run this app.")
                sys.exit(1)


def importPySide():
    global QtCore, QtGui, QtNetwork, QtWebKit, QtUiTools, Signal, Slot, loadUI

    try:
        from PySide import QtCore, QtGui, QtNetwork, QtWebKit, QtUiTools
        from PySide.QtCore import Signal, Slot

        def loadUI(uiFilename):
            class UiLoader(QtUiTools.QUiLoader):
                def __init__(self):
                    QtUiTools.QUiLoader.__init__(self)
                    self.rootWidget = None

                def createWidget(self, className, parent=None, name=''):
                    widget = QtUiTools.QUiLoader.createWidget(
                            self, className, parent, name)

                    if parent is None:
                        self.rootWidget = widget
                    elif parent is not None:
                        setattr(self.rootWidget, name, widget)

                    if parent is not None:
                        setattr(parent, name, widget)

                    return widget

            return UiLoader().load(uiFilename)

        return True

    except ImportError:
        return False


def importPyQt():
    global QtCore, QtGui, QtNetwork, QtWebKit, QtUiTools, Signal, Slot, loadUI

    try:
        import sip
        sip.setapi('QString', 2)
        sip.setapi('QVariant', 2)

        from PyQt4 import QtCore, QtGui, QtNetwork, QtWebKit, uic
        from PyQt4.QtCore import pyqtSignal as Signal
        from PyQt4.QtCore import pyqtSlot as Slot
        QtUiTools = object()

        def loadUI(uiFilename, baseinstance=None):
            return uic.loadUi(uiFilename, baseinstance)

        return True

    except ImportError:
        return False
