# -*- coding: utf-8 -*-

# Copyright (c) 2011 Christopher S. Case and David H. Bronke
# Licensed under the MIT license; see the LICENSE file for details.

from Qt import QtCore, Signal

import re, string, logging

NETSTRING_BASE = 10

logger = logging.getLogger("gmusic.common.netstrings")


class NetstringReader(QtCore.QObject):
    dataReady = Signal(str)

    digits = re.compile(r'[0-9]*$')

    def __init__(self):
        QtCore.QObject.__init__(self)
        self.buffer = ""

    def onData(self, data):
        self.buffer += str(data)
        self.readNetstring()

    def readNetstring(self):
        while True:
            if ':' not in self.buffer:
                # Not enough data to parse this message yet.
                return

            colonPos = self.buffer.index(':')
            messageLength = self.buffer[:colonPos]
            if not all([x in (string.digits + string.lowercase) for x in
                        messageLength]):
                logger.warning("WARNING: Ignoring garbage data before message \
                length specifier!")
                match = self.digits.search(messageLength)
                messageLength = match.group(0)

            if len(messageLength) == 0:
                logger.warning("Invalid message length! Discarding buffer \
                contents.")
                self.buffer = ""
                return

            messageLength = int(messageLength, NETSTRING_BASE)

            if len(self.buffer) < colonPos + messageLength + 2:
                # Not enough data to parse this message yet.
                return

            self.buffer = self.buffer[colonPos + 1:]

            if self.buffer[messageLength] != ',':
                logger.error("ERROR: Incorrectly formatted netstring!")
                return

            #logger.debug("Reading %d-byte message.", messageLength)

            message = self.buffer[:messageLength]

            self.buffer = self.buffer[messageLength + 1:]

            self.dataReady.emit(message)

class NetstringWriter(QtCore.QObject):
    dataReady = Signal(QtCore.QByteArray)

    def __init__(self):
        QtCore.QObject.__init__(self)

    def digit_to_char(self, digit):
        return (string.digits + string.lowercase)[digit]

    def str_base(self, number, base):
        if number < 0:
            return '-' + self.str_base(-number, base)
        else:
            (d, m) = divmod(number,base)
            if d:
                return self.str_base(d, base) + self.digit_to_char(m)
            else:
                return self.digit_to_char(m)

    def makeNetstring(self, input):
        data = "%s:%s," % (self.str_base(len(input), NETSTRING_BASE), input)
        return data

    def onData(self, data):
        self.dataReady.emit(self.makeNetstring(data))

