# -*- coding: utf-8 -*-

# Copyright (c) 2009-2011 Christopher S. Case and David H. Bronke
# Licensed under the MIT license; see the LICENSE file for details.

import sqlite3
import os

from Qt import QtCore, QtNetwork


cookieJar = None


class NetworkCookieJar(QtNetwork.QNetworkCookieJar):
    _settings = {
            "saveSessionCookies": True,
            }

    def __init__(self, parent=None, session="Default Session"):
        self.parent = parent
        self.session = session
        self.cachePath = os.path.expanduser(os.path.join(
                "~", ".cache", "gmusic"))
        if not os.path.exists(self.cachePath):
            os.makedirs(self.cachePath)
        self.cookieDB = os.path.join(self.cachePath, "cookies.db")
        QtNetwork.QNetworkCookieJar.__init__(self)

    #FIXME: Make thread-safe!

    def loadCookiesFromDisk(self):
        if os.path.exists(self.cookieDB):
            def intToBool(val):
                if val == 0:
                    return False
                else:
                    return True

            conn = sqlite3.connect(self.cookieDB)
            c = conn.cursor()
            c.execute('''select name, value, domain, expiration, httpOnly,
                        secure, text
                    from cookies
                    where session=?''',
                    (self.session, ))

            cookies = list()
            for cdef in c:
                cookie = QtNetwork.QNetworkCookie(
                        QtCore.QByteArray(str(cdef[0])),
                        QtCore.QByteArray(str(cdef[1]))
                        )
                cookie.setDomain(cdef[2])
                cookie.setExpirationDate(
                        QtCore.QDateTime.fromString(
                            cdef[3], "yyyy-MM-dd-HH-mm-ss"
                            ))
                cookie.setHttpOnly(intToBool(cdef[4]))
                cookie.setSecure(intToBool(cdef[5]))
                cookie.setPath(cdef[6])
                cookies.append(cookie)

            c.close()
            conn.close()
            self.setAllCookies(cookies)

    def saveCookiesToDisk(self):
        # Get the settings path.
        # Write cookie
        dbExists = os.path.exists(self.cookieDB)
        conn = sqlite3.connect(self.cookieDB)
        c = conn.cursor()

        if dbExists:
            c.execute('delete from cookies')
        else:
            c.execute('''create table cookies
                    (session text, name blob, value blob, domain text,
                    expiration text, httpOnly int, secure int, text path)''')

        def boolToInt(val):
            if val:
                return 1
            else:
                return 0

        for cookie in self.allCookies():
            if not cookie.isSessionCookie() \
                    or self._settings["saveSessionCookies"]:
                c.execute('insert into cookies values(?, ?, ?, ?, ?, ?, ?, ?)',
                        (
                            self.session,
                            bytes(cookie.name()),
                            bytes(cookie.value()),
                            str(cookie.domain()),
                            str(cookie.expirationDate().toString(
                                "yyyy-MM-dd-HH-mm-ss")),
                            boolToInt(cookie.isHttpOnly()),
                            boolToInt(cookie.isSecure()),
                            str(cookie.path())
                            ))
        conn.commit()
        c.close()
        conn.close()


def getCookieJar():
    global cookieJar

    if cookieJar is None:
        print "Making new shiny NetworkCookieJar."
        cookieJar = NetworkCookieJar()
        cookieJar.loadCookiesFromDisk()

    return cookieJar
