# -*- coding: utf-8 -*-

# Copyright (c) 2011 Christopher S. Case and David H. Bronke
# Licensed under the MIT license; see the LICENSE file for details.

# Python includes
import sys

has_libnotify = True
has_growl = True
has_snarl = True

try:
    import pynotify
except:
    has_libnotify = False

try:
    import growl
except:
    has_growl = False

try:
    import snarl
except:
    has_snarl = False

class Notify(object):
    notifier = None
    appname = ""

    def __init__(self, appname):
        self.appname = appname

        # Our preferences, in order:
        # libnotify
        # growl
        # snarl
        # systemtray bubble
        if has_libnotify:
            self.notifier = LibNotify(self.appname)
        elif has_growl:
            self.notifier = GrowlNotify(self.appname)
        elif has_snarl:
            self.notifier = SnarlNotify(self.appname)
        else:
            print "No Notifier found."

    def notify(self, title, message, icon):
        self.notifier.notify(title, message, icon)

class LibNotify(object):

    def __init__(self, appname):
        if not pynotify.init(appname):
            print "PyNotify failed to initialize with appname:", appname

    def notify(self, title, message, icon):
        notification = pynotify.Notification(title, message, icon)
        notification.show()

class GrowlNotify(object):
    pass

class SnarlNotify(object):
    pass

