#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2011 Christopher S. Case and David H. Bronke
# Licensed under the MIT license; see the LICENSE file for details.

# Import python modules
import sys
import os
import logging
import logging.config

# Python Qt Bindings
from classes import Qt

# Initialize Desired Qt Bindings
if '--PyQt' in sys.argv:
    Qt.initialize("PyQt")
elif '--PyQt4' in sys.argv:
    Qt.initialize("PyQt4")
elif '--PySide' in sys.argv:
    Qt.initialize("PySide")
elif '-h' in sys.argv or '--help' in sys.argv:
    print __file__, "[OPTIONS]"
    print "--PyQt, --PyQt4          Run application with PyQt4 bindings"
    print "--PySide                 Run application with PySide bindings (default)"
    print "-h, --help               Print this help text"
    sys.exit()
else:
    Qt.initialize()


# Import python qt modules
from classes.Qt import QtCore, QtGui

# GMusic Imports
from classes.main import GMain

# Application setup
app = QtGui.QApplication(sys.argv)
QtCore.QCoreApplication.setOrganizationName('GNE Solutions, LLC')
QtCore.QCoreApplication.setOrganizationDomain('gnesolutions.com')
QtCore.QCoreApplication.setApplicationName('GMusic')

# Get application path
app.setProperty("AppPath", os.path.dirname(os.path.realpath(__file__)))

# Logging setup
try:
    logging.config.fileConfig(os.path.join(app.property("AppPath"), "logging.conf"))
    logger = logging.getLogger("gmusic")
except:
    logging.basicConfig()
    logger = logging.getLogger("gmusic")
    logger.warn("Failed to find configuration file.")

logger.info("Welcome to GMusic v0.2.0")

# Main Application Script
main = GMain()
main.show()

# Enter the Qt Eventloop
sys.exit(app.exec_())
